# flake8: noqa

# import apis into api package
from team_member_server_sdk.api.server_requests_api import ServerRequestsApi
from team_member_server_sdk.api.team_member_api import TeamMemberApi
from team_member_server_sdk.api.team_member_role_api import TeamMemberRoleApi




# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.wrapped_response_team_member_access_response import WrappedResponseTeamMemberAccessResponse  # noqa: E501

class TestWrappedResponseTeamMemberAccessResponse(unittest.TestCase):
    """WrappedResponseTeamMemberAccessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseTeamMemberAccessResponse:
        """Test WrappedResponseTeamMemberAccessResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseTeamMemberAccessResponse`
        """
        model = WrappedResponseTeamMemberAccessResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseTeamMemberAccessResponse(
                done = true,
                result = team_member_server_sdk.models.team_member_access_response.TeamMemberAccessResponse(
                    portal_member_id = 56, 
                    team_member_role = team_member_server_sdk.models.team_member_role_schema.TeamMemberRoleSchema(
                        id = 56, 
                        title = '', 
                        enabled_at = 56, 
                        action_codes = [
                            ''
                            ], 
                        scopes = team_member_server_sdk.models.scope_schema.ScopeSchema(
                            course_ids = [
                                56
                                ], 
                            community_ids = [
                                56
                                ], ), ), )
            )
        else:
            return WrappedResponseTeamMemberAccessResponse(
                result = team_member_server_sdk.models.team_member_access_response.TeamMemberAccessResponse(
                    portal_member_id = 56, 
                    team_member_role = team_member_server_sdk.models.team_member_role_schema.TeamMemberRoleSchema(
                        id = 56, 
                        title = '', 
                        enabled_at = 56, 
                        action_codes = [
                            ''
                            ], 
                        scopes = team_member_server_sdk.models.scope_schema.ScopeSchema(
                            course_ids = [
                                56
                                ], 
                            community_ids = [
                                56
                                ], ), ), ),
        )
        """

    def testWrappedResponseTeamMemberAccessResponse(self):
        """Test WrappedResponseTeamMemberAccessResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ActionCode(str, Enum):
    """
    ActionCode
    """

    """
    allowed enum values
    """
    VIEW_DASHBOARD_STATISTICS = 'view_dashboard_statistics'
    VIEW_QUIZ_STATISTICS = 'view_quiz_statistics'
    VIEW_CERTIFICATE_STATISTICS = 'view_certificate_statistics'
    VIEW_LEADERBOARD_STATISTICS = 'view_leaderboard_statistics'
    VIEW_AI_ASSISTANT_STATISTICS = 'view_ai_assistant_statistics'
    VIEW_COURSE = 'view_course'
    VIEW_ANY_COURSE = 'view_any_course'
    EDIT_COURSE = 'edit_course'
    EDIT_ANY_COURSE = 'edit_any_course'
    CREATE_COURSE = 'create_course'
    ARCHIVE_COURSE = 'archive_course'
    ARCHIVE_ANY_COURSE = 'archive_any_course'
    REMOVE_COURSE = 'remove_course'
    REMOVE_ANY_COURSE = 'remove_any_course'
    VIEW_FILE = 'view_file'
    EDIT_FILE = 'edit_file'
    UPLOAD_FILE = 'upload_file'
    DOWNLOAD_FILE = 'download_file'
    REMOVE_FILE = 'remove_file'
    VIEW_LANDING_PAGE = 'view_landing_page'
    EDIT_LANDING_PAGE = 'edit_landing_page'
    CREATE_LANDING_PAGE = 'create_landing_page'
    REMOVE_LANDING_PAGE = 'remove_landing_page'
    VIEW_OPTIN_PROCESS = 'view_optin_process'
    EDIT_OPTIN_PROCESS = 'edit_optin_process'
    CREATE_OPTIN_PROCESS = 'create_optin_process'
    REMOVE_OPTIN_PROCESS = 'remove_optin_process'
    VIEW_CALENDAR_EVENT = 'view_calendar_event'
    EDIT_CALENDAR_EVENT = 'edit_calendar_event'
    CREATE_CALENDAR_EVENT = 'create_calendar_event'
    REMOVE_CALENDAR_EVENT = 'remove_calendar_event'
    VIEW_LEADERBOARD = 'view_leaderboard'
    EDIT_LEADERBOARD = 'edit_leaderboard'
    VIEW_SHOUTOUT_BOX = 'view_shoutout_box'
    EDIT_SHOUTOUT_BOX = 'edit_shoutout_box'
    VIEW_AI_VIDEO = 'view_ai_video'
    EDIT_AI_VIDEO = 'edit_ai_video'
    GENERATE_AI_VIDEO = 'generate_ai_video'
    REMOVE_AI_VIDEO = 'remove_ai_video'
    GENERATE_AI_COURSE = 'generate_ai_course'
    VIEW_CERTIFICATE = 'view_certificate'
    EDIT_CERTIFICATE = 'edit_certificate'
    CREATE_CERTIFICATE = 'create_certificate'
    REMOVE_CERTIFICATE = 'remove_certificate'
    VIEW_AI_ASSISTANT = 'view_ai_assistant'
    EDIT_AI_ASSISTANT = 'edit_ai_assistant'
    VIEW_MOBILE_APP = 'view_mobile_app'
    VIEW_DESIGN_SETTINGS = 'view_design_settings'
    EDIT_DESIGN_SETTINGS = 'edit_design_settings'
    VIEW_COMMUNITY = 'view_community'
    VIEW_ANY_COMMUNITY = 'view_any_community'
    EDIT_COMMUNITY = 'edit_community'
    EDIT_ANY_COMMUNITY = 'edit_any_community'
    CREATE_COMMUNITY = 'create_community'
    REMOVE_COMMUNITY = 'remove_community'
    REMOVE_ANY_COMMUNITY = 'remove_any_community'
    VIEW_COMMUNITY_MODERATOR = 'view_community_moderator'
    CREATE_COMMUNITY_MODERATOR = 'create_community_moderator'
    REMOVE_COMMUNITY_MODERATOR = 'remove_community_moderator'
    VIEW_USER = 'view_user'
    EDIT_USER = 'edit_user'
    EXPORT_USER = 'export_user'
    REMOVE_USER = 'remove_user'
    VIEW_ORDER = 'view_order'
    CREATE_ORDER = 'create_order'
    EXPORT_ORDER = 'export_order'
    IMPORT_ORDER = 'import_order'
    REMOVE_ORDER = 'remove_order'
    VIEW_CHATS = 'view_chats'
    SEND_MESSAGE_CHAT = 'send_message_chat'
    EDIT_CHAT = 'edit_chat'
    VIEW_PAYMENT_SETTINGS = 'view_payment_settings'
    VIEW_GENERAL_SETTINGS = 'view_general_settings'
    EDIT_GENERAL_SETTINGS = 'edit_general_settings'
    VIEW_EMAIL_SETTINGS = 'view_email_settings'
    EDIT_EMAIL_SETTINGS = 'edit_email_settings'
    VIEW_PAYMENT_PROVIDER_SETTINGS = 'view_payment_provider_settings'
    EDIT_PAYMENT_PROVIDER_SETTINGS = 'edit_payment_provider_settings'
    VIEW_CUSTOMER_SUPPORT_SETTINGS = 'view_customer_support_settings'
    EDIT_CUSTOMER_SUPPORT_SETTINGS = 'edit_customer_support_settings'
    VIEW_INTEGRATIONS_SETTINGS = 'view_integrations_settings'
    EDIT_INTEGRATIONS_SETTINGS = 'edit_integrations_settings'
    VIEW_ANALYTICS_SETTINGS = 'view_analytics_settings'
    EDIT_ANALYTICS_SETTINGS = 'edit_analytics_settings'
    VIEW_LEGAL_DOCUMENTS_SETTINGS = 'view_legal_documents_settings'
    EDIT_LEGAL_DOCUMENTS_SETTINGS = 'edit_legal_documents_settings'
    VIEW_AFFILIATE_SETTINGS = 'view_affiliate_settings'
    EDIT_AFFILIATE_SETTINGS = 'edit_affiliate_settings'
    VIEW_COMMUNITY_SETTINGS = 'view_community_settings'
    EDIT_COMMUNITY_SETTINGS = 'edit_community_settings'
    VIEW_AI_INTERFACE_SETTINGS = 'view_ai_interface_settings'
    EDIT_AI_INTERFACE_SETTINGS = 'edit_ai_interface_settings'
    VIEW_MEMBERS_SETTINGS = 'view_members_settings'
    EDIT_MEMBERS_SETTINGS = 'edit_members_settings'

    @classmethod
    def from_json(cls, json_str: str) -> ActionCode:
        """Create an instance of ActionCode from a JSON string"""
        return ActionCode(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ActionOperation(str, Enum):
    """
    ActionOperation
    """

    """
    allowed enum values
    """
    ADD = 'add'
    REMOVE = 'remove'

    @classmethod
    def from_json(cls, json_str: str) -> ActionOperation:
        """Create an instance of ActionOperation from a JSON string"""
        return ActionOperation(json.loads(json_str))


